/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: CarDeployableMetadata.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.car.impl;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import org.ow2.util.ee.deploy.api.deployable.CARDeployable;
import org.ow2.util.ee.metadata.car.api.ICarClassMetadata;
import org.ow2.util.ee.metadata.car.api.ICarDeployableMetadata;
import org.ow2.util.ee.metadata.common.api.struct.IEnvEntry;
import org.ow2.util.ee.metadata.common.impl.AbsEnvironmentRefAccessor;

/**
 * Metadata of a client archive.
 * @author Gael Lalire
 */
public class CarDeployableMetadata extends AbsEnvironmentRefAccessor implements ICarDeployableMetadata {

    /**
     * List of class annotations metadata.
     */
    private Map<String, ICarClassMetadata> carClassMetadataMap = null;

    /**
     * The car deployable.
     */
    private CARDeployable carDeployable;

    /**
     * envEntryCollection.
     */
    private Collection<? extends IEnvEntry> envEntryCollection;

    /**
     * Metadata-complete element has been set to true or false.
     */
    private boolean isMetadacomplete = false;

    /**
     * Constructor.
     * @param carDeployable the client archive deployable
     */
    public CarDeployableMetadata(final CARDeployable carDeployable) {
        this.carDeployable = carDeployable;
        carClassMetadataMap = new HashMap<String, ICarClassMetadata>();
        envEntryCollection = new ArrayList<IEnvEntry>();
    }

    /**
     * Add annotation metadata for a given class.
     * @param carClassMetadata metadata of a class.
     */
    public void addCarClassMetadata(final ICarClassMetadata carClassMetadata) {
        String key = carClassMetadata.getJClass().getName();
        // already exists ?
        if (carClassMetadataMap.containsKey(key)) {
            throw new IllegalStateException("addCarClassMetadata : key already exists");
        }
        carClassMetadataMap.put(key, carClassMetadata);
    }

    /**
     * Get class annotation metadata.
     * @param className key of the map of annotations bean.
     * @return Bean annotation metadata of a given name.
     */
    public ICarClassMetadata getCarClassMetadata(final String className) {
        return carClassMetadataMap.get(className);
    }

    /**
     * Get collections of bean annotation metadata.
     * @return collections of bean annotation metadata.
     */
    public Collection<ICarClassMetadata> getCarClassMetadataCollection() {
        return carClassMetadataMap.values();
    }

    /**
     * @return the client archive
     */
    public CARDeployable getDeployable() {
        return carDeployable;
    }

    /**
     * {@inheritDoc}
     */
    public Collection<? extends IEnvEntry> getEnvEntryCollection() {
        return envEntryCollection;
    }

    /**
     * {@inheritDoc}
     */
    public void setEnvEntryCollection(final Collection<? extends IEnvEntry> envEntryCollection) {
        this.envEntryCollection = envEntryCollection;
    }

    /**
     * @return true if metadata-complete flag is enabled on the deployable.
     */
    public boolean isMetadataComplete() {
        return isMetadacomplete;
    }

    /**
     * Allow to define if this metadata is annotation completed or not.
     */
    public void setMetadataComplete(final boolean complete) {
        this.isMetadacomplete = complete;
    }

}
