/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CarClassMetadataConfigurator.java 6167 2012-02-09 16:46:06Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.car.impl.configurator;

import java.util.List;
import java.util.Set;

import org.ow2.util.ee.metadata.car.api.ICarClassMetadata;
import org.ow2.util.ee.metadata.car.api.ICarFieldMetadata;
import org.ow2.util.ee.metadata.car.api.ICarMethodMetadata;
import org.ow2.util.ee.metadata.car.impl.CarClassMetadata;
import org.ow2.util.ee.metadata.car.impl.CarDeployableMetadata;
import org.ow2.util.ee.metadata.car.impl.specific.ISpecificCarDeployableMetadataConfigurator;
import org.ow2.util.ee.metadata.common.impl.configurator.CommonClassMetadataConfigurator;
import org.ow2.util.scan.api.configurator.IFieldConfigurator;
import org.ow2.util.scan.api.configurator.IMethodConfigurator;
import org.ow2.util.scan.api.metadata.structures.JClass;
import org.ow2.util.scan.api.metadata.structures.JField;
import org.ow2.util.scan.api.metadata.structures.JMethod;


/**
 * CarClassMetadataConfigurator.
 * @author Gael Lalire
 */
public class CarClassMetadataConfigurator extends
        CommonClassMetadataConfigurator<ICarClassMetadata, ICarMethodMetadata, ICarFieldMetadata> {

    /**
     * annotationParsingDesactived.
     */
    private boolean annotationParsingDesactived;

    /**
     * CarClassMetadataConfigurator.
     * @param jClass signature
     * @param carArchiveMetadata parent
     * @param annotationParsingDesactived annotationParsingDesactived
     * @param specificCarDeployableFactoryList list of specific metadata
     *        factories
     */
    public CarClassMetadataConfigurator(final JClass jClass, final CarDeployableMetadata carArchiveMetadata,
            final boolean annotationParsingDesactived,
            final List<ISpecificCarDeployableMetadataConfigurator> specificCarDeployableFactoryList) {
        super(new CarClassMetadata(jClass, carArchiveMetadata), specificCarDeployableFactoryList);
        this.annotationParsingDesactived = annotationParsingDesactived;
        if (!annotationParsingDesactived) {
            registerAnnotationVisitor();
        }
    }

    /**
     * @param jField signature
     * @return configurator
     */
    @Override
    protected IFieldConfigurator createFieldMetadataConfigurator(final JField jField) {
        return new CarFieldMetadataConfigurator(jField, getClassMetadata(), annotationParsingDesactived,
                getSpecificClassConfiguratorList());
    }

    /**
     * @param jMethod signature
     * @return configurator
     */
    @Override
    protected IMethodConfigurator createMethodMetadataConfigurator(final JMethod jMethod) {
        return new CarMethodMetadataConfigurator(jMethod, getClassMetadata(), annotationParsingDesactived,
                getSpecificClassConfiguratorList());
    }

    /**
     * add class to archive.
     * @param referencedClasses you may fill this set with class referenced in current metadata
     */
    @Override
    public void configurationComplete(final Set<String> referencedClasses) {
       ICarClassMetadata carClassMetadata = getClassMetadata();
       carClassMetadata.getCarDeployableMetadata().addCarClassMetadata(carClassMetadata);
       super.configurationComplete(referencedClasses);
    }

}
