/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CarDeployableMetadataConfigurator.java 6167 2012-02-09 16:46:06Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.car.impl.configurator;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.ee.deploy.api.deployable.CARDeployable;
import org.ow2.util.ee.metadata.car.impl.CarDeployableMetadata;
import org.ow2.util.ee.metadata.car.impl.specific.ISpecificCarDeployableMetadataConfigurator;
import org.ow2.util.scan.api.configurator.IArchiveConfigurator;
import org.ow2.util.scan.api.configurator.IClassConfigurator;
import org.ow2.util.scan.api.metadata.structures.JClass;

/**
 * EjbJarArchiveMetadataConfigurator.
 * @author Gael Lalire
 */
public class CarDeployableMetadataConfigurator implements IArchiveConfigurator {

    /**
     * The list of specific configurator.
     */
    private List<ISpecificCarDeployableMetadataConfigurator> specificCarDeployableFactoryList;

    /**
     * archive metadata.
     */
    private CarDeployableMetadata carDeployableMetadata;

    /**
     * annotationParsingDesactived.
     */
    private boolean annotationParsingDesactived;

    /**
     * Constructor.
     * @param carDeployable the client archive
     */
    public CarDeployableMetadataConfigurator(final CARDeployable carDeployable) {
        this.carDeployableMetadata = new CarDeployableMetadata(carDeployable);
        this.annotationParsingDesactived = false;
        specificCarDeployableFactoryList = new ArrayList<ISpecificCarDeployableMetadataConfigurator>();
    }

    /**
     * @param jClass signature
     * @return class configurator
     */
    public IClassConfigurator createClassConfigurator(final JClass jClass) {
        return new CarClassMetadataConfigurator(jClass, this.carDeployableMetadata, annotationParsingDesactived,
                specificCarDeployableFactoryList);
    }

    /**
     * @return the archive metadata
     */
    public CarDeployableMetadata getCarDeployableMetadata() {
        return this.carDeployableMetadata;
    }

    /**
     * Set annotationParsingDesactived.
     * @param annotationParsingDesactived true if you want to desactive annotation parsing
     */
    public void setAnnotationParsingDesactived(final boolean annotationParsingDesactived) {
        this.annotationParsingDesactived = annotationParsingDesactived;
    }

    /**
     * @param specificCarDeployableFactory add a specific configurator to the list
     */
    public void addSpecificMetadataConfigurator(final ISpecificCarDeployableMetadataConfigurator specificCarDeployableFactory) {
        specificCarDeployableFactoryList.add(specificCarDeployableFactory);
    }

    /**
     * @return the list of specific configurator.
     */
    public List<ISpecificCarDeployableMetadataConfigurator> getSpecificEjbJarDeployableFactoryList() {
        return specificCarDeployableFactoryList;
    }


}
