/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: SpecificCarClassMetadata.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.car.impl.specific;

import org.ow2.util.ee.metadata.car.api.ICarClassMetadata;
import org.ow2.util.ee.metadata.car.api.ICarDeployableMetadata;
import org.ow2.util.ee.metadata.car.api.ICarFieldMetadata;
import org.ow2.util.ee.metadata.car.api.ICarMethodMetadata;
import org.ow2.util.ee.metadata.common.impl.specific.SpecificCommonClassMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificClassMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificFieldMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificMethodMetadata;

/**
 * You can extends this class to create a specific car class metadata.
 * @param <SC> specific class metadata
 * @param <SM> specific method metadata
 * @param <SF> specific field metadata
 * @author Gael Lalire
 */
public class SpecificCarClassMetadata<
    SC extends ISpecificClassMetadata<SC, SM, SF>,
    SM extends ISpecificMethodMetadata<SC, SM, SF>,
    SF extends ISpecificFieldMetadata<SC, SM, SF>>
        extends SpecificCommonClassMetadata<ICarClassMetadata, ICarMethodMetadata, ICarFieldMetadata, SC, SM, SF>
        implements ICarClassMetadata {

    /**
     * The standard car class metadata.
     */
    private ICarClassMetadata carClassMetadata;

    /**
     * Construct delegation.
     * @param carClassMetadata the standard car class metadata.
     */
    protected SpecificCarClassMetadata(final ICarClassMetadata carClassMetadata) {
        super(carClassMetadata);
        this.carClassMetadata = carClassMetadata;
    }

    /**
     * {@inheritDoc}
     */
    public ICarDeployableMetadata getCarDeployableMetadata() {
        return carClassMetadata.getCarDeployableMetadata();
    }

    /**
     * {@inheritDoc}
     */
    public boolean isCallbackHandler() {
        return carClassMetadata.isCallbackHandler();
    }

    /**
     * {@inheritDoc}
     */
    public void setCallbackHandler(final boolean callbackHandler) {
        carClassMetadata.setCallbackHandler(callbackHandler);
    }

}
